@@ -29,5 +29,5 @@ print $_
         and not /write_bg/
         and not /write_logo/
         and not /write_favicon/
-        and not /ajax.googleapis.com/
-        and not /Grab Google/;
+        and not /code.jquery.com/
+        and not /Grab jQuery/;
